@@ -1,5 +1,5 @@
 # -*- Mode: cperl; cperl-indent-level: 4 -*-
-# $Id: Harness.pm,v 1.14.2.11 2001/12/18 03:17:48 schwern Exp $
+# $Id: Harness.pm,v 1.14.2.5 2001/08/12 02:55:08 schwern Exp $
 
 package Test::Harness;
 
@@ -22,15 +22,10 @@ use vars qw($VERSION $Verbose $Switches $Have_Devel_Corestack $Curtest
 
 $Have_Devel_Corestack = 0;
 
-$VERSION = '2.00';
+$VERSION = "2.00_00";
 
 $ENV{HARNESS_ACTIVE} = 1;
 
-END {
-    # For VMS.
-    delete $ENV{HARNESS_ACTIVE};
-}
-
 # Some experimental versions of OS/2 build have broken $?
 my $Ignore_Exitcode = $ENV{HARNESS_IGNORE_EXITCODE};
 
@@ -133,14 +128,18 @@ will generate
     FAILED tests 1, 3, 6
     Failed 3/6 tests, 50.00% okay
 
-=item B<test names>
 
-Anything after the test number but before the # is considered to be
-the name of the test.
+=item B<$Test::Harness::verbose>
 
-  ok 42 this is the name of the test
+The global variable $Test::Harness::verbose is exportable and can be
+used to let runtests() display the standard output of the script
+without altering the behavior otherwise.
 
-Currently, Test::Harness does nothing with this information.
+=item B<$Test::Harness::switches>
+
+The global variable $Test::Harness::switches is exportable and can be
+used to set perl command line options used for running the test
+script(s). The default value is C<-w>.
 
 =item B<Skipping tests>
 
@@ -218,38 +217,6 @@ test script, please use a comment.
 =back
 
 
-=head2 Taint mode
-
-Test::Harness will honor the C<-T> in the #! line on your test files.  So
-if you begin a test with:
-
-    #!perl -T
-
-the test will be run with taint mode on.
-
-
-=head2 Configuration variables.
-
-These variables can be used to configure the behavior of
-Test::Harness.  They are exported on request.
-
-=over 4
-
-=item B<$Test::Harness::verbose>
-
-The global variable $Test::Harness::verbose is exportable and can be
-used to let runtests() display the standard output of the script
-without altering the behavior otherwise.
-
-=item B<$Test::Harness::switches>
-
-The global variable $Test::Harness::switches is exportable and can be
-used to set perl command line options used for running the test
-script(s). The default value is C<-w>.
-
-=back
-
-
 =head2 Failure
 
 It will happen, your tests will fail.  After you mop up your ego, you
@@ -338,7 +305,7 @@ sub runtests {
     my($tot, $failedtests) = _run_all_tests(@tests);
     _show_results($tot, $failedtests);
 
-    my $ok = _all_ok($tot);
+    my $ok = ($tot->{bad} == 0 && $tot->{max});
 
     assert(($ok xor keys %$failedtests), 
            q{ok status jives with $failedtests});
@@ -348,20 +315,6 @@ sub runtests {
 
 =begin _private
 
-=item B<_all_ok>
-
-  my $ok = _all_ok(\%tot);
-
-Tells you if this test run is overall successful or not.
-
-=cut
-
-sub _all_ok {
-    my($tot) = shift;
-
-    return $tot->{bad} == 0 && ($tot->{max} || $tot->{skipped}) ? 1 : 0;
-}
-
 =item B<_globdir>
 
   my @files = _globdir $dir;
@@ -440,16 +393,30 @@ sub _run_all_tests {
                 bench    => 0,
                );
 
-    local($ENV{'PERL5LIB'}) = $Strap->_INC2PERL5LIB;
+    # pass -I flags to children
+    my $old5lib = $ENV{PERL5LIB};
+
+    # VMS has a 255-byte limit on the length of %ENV entries, so
+    # toss the ones that involve perl_root, the install location
+    # for VMS
+    my $new5lib;
+    if ($^O eq 'VMS') {
+        $new5lib = join($Config{path_sep}, grep {!/perl_root/i;} @INC);
+        $Switches =~ s/-(\S*[A-Z]\S*)/"-$1"/g;
+    }
+    else {
+        $new5lib = join($Config{path_sep}, @INC);
+    }
+
+    local($ENV{'PERL5LIB'}) = $new5lib;
 
     my @dir_files = _globdir $Files_In_Dir if defined $Files_In_Dir;
     my $t_start = new Benchmark;
 
-    my $width = _leader_width(@tests);
     foreach my $tfile (@tests) {
         $Strap->_reset_file_state;
 
-        my($leader, $ml) = _mk_leader($tfile, $width);
+        my($leader, $ml) = _mk_leader($tfile);
         print $leader;
 
         my $fh = _open_test($tfile);
@@ -471,7 +438,6 @@ sub _run_all_tests {
         while (<$fh>) {
             print if $Verbose;
 
-            $Strap->{line}++;
             if( _parse_header($_, \%test, \%tot) ) {
                 warn "Test header seen twice!\n" if $seen_header;
 
@@ -571,37 +537,38 @@ sub _run_all_tests {
                 @dir_files = @new_dir_files;
             }
         }
-
-        close $fh;
     }
     $tot{bench} = timediff(new Benchmark, $t_start);
 
-    $Strap->_restore_PERL5LIB;
+    if ($^O eq 'VMS') {
+        if (defined $old5lib) {
+            $ENV{PERL5LIB} = $old5lib;
+        } else {
+            delete $ENV{PERL5LIB};
+        }
+    }
 
     return(\%tot, \%failedtests);
 }
 
 =item B<_mk_leader>
 
-  my($leader, $ml) = _mk_leader($test_file, $width);
+  my($leader, $ml) = _mk_leader($test_file);
 
 Generates the 't/foo........' $leader for the given $test_file as well
 as a similar version which will overwrite the current line (by use of
 \r and such).  $ml may be empty if Test::Harness doesn't think you're
 on TTY.
 
-The $width is the width of the "yada/blah.." string.
-
 =cut
 
 sub _mk_leader {
-    my($te, $width) = @_;
-    chomp($te);
-    $te =~ s/\.\w+$/./;
+    my $te = shift;
+    chomp($te);      # XXX chomp?
 
     if ($^O eq 'VMS') { $te =~ s/^.*\.t\./\[.t./s; }
     my $blank = (' ' x 77);
-    my $leader = "$te" . '.' x ($width - length($te));
+    my $leader = "$te" . '.' x (20 - length($te));
     my $ml = "";
 
     $ml = "\r$blank\r$leader"
@@ -610,29 +577,6 @@ sub _mk_leader {
     return($leader, $ml);
 }
 
-=item B<_leader_width>
-
-  my($width) = _leader_width(@test_files);
-
-Calculates how wide the leader should be based on the length of the
-longest test name.
-
-=cut
-
-sub _leader_width {
-    my $maxlen = 0;
-    my $maxsuflen = 0;
-    foreach (@_) {
-        my $suf    = /\.(\w+)$/ ? $1 : '';
-        my $len    = length;
-        my $suflen = length $suf;
-        $maxlen    = $len    if $len    > $maxlen;
-        $maxsuflen = $suflen if $suflen > $maxsuflen;
-    }
-    # + 3 : we want three dots between the test name and the "ok"
-    return $maxlen + 3 - $maxsuflen;
-}
-
 
 sub _show_results {
     my($tot, $failedtests) = @_;
@@ -640,7 +584,7 @@ sub _show_results {
     my $pct;
     my $bonusmsg = _bonusmsg($tot);
 
-    if (_all_ok($tot)) {
+    if ($tot->{bad} == 0 && $tot->{max}) {
         print "All tests successful$bonusmsg.\n";
     } elsif (!$tot->{tests}){
         die "FAILED--no tests were run for some reason.\n";
@@ -650,10 +594,9 @@ sub _show_results {
             "alas--no output ever seen\n";
     } else {
         $pct = sprintf("%.2f", $tot->{good} / $tot->{tests} * 100);
-        my $percent_ok = 100*$tot->{ok}/$tot->{max};
         my $subpct = sprintf " %d/%d subtests failed, %.2f%% okay.",
                               $tot->{max} - $tot->{ok}, $tot->{max}, 
-                              $percent_ok;
+                              100*$tot->{ok}/$tot->{max};
 
         my($fmt_top, $fmt) = _create_fmts($failedtests);
 
@@ -724,14 +667,20 @@ sub _open_test {
     }
 }
 
+sub _run_one_test {
+    my($test) = @_;
+
+    
+}
+
 
 sub _parse_test_line {
     my($line, $test, $tot) = @_;
 
     my %result;
     if ( $Strap->_is_test($line, \%result) ) {
-        $test->{'next'} ||= 1;
-        my $this = $test->{'next'};
+        $test->{next} ||= 1;
+        my $this = $test->{next};
 
         my($not, $tnum) = (!$result{ok}, $result{number});
 
@@ -846,8 +795,16 @@ sub _close_fh {
 sub _set_switches {
     my($test) = shift;
 
+    local *TEST;
+    open(TEST, $test) or print "can't open $test. $!\n";
+    my $first = <TEST>;
     my $s = $Switches;
-    $s .= $Strap->_switches($test);
+    $s .= " $ENV{'HARNESS_PERL_SWITCHES'}"
+      if exists $ENV{'HARNESS_PERL_SWITCHES'};
+    $s .= join " ", q[ "-T"], map {qq["-I$_"]} @INC
+      if $first =~ /^#!.*\bperl.*-\w*T/;
+
+    close(TEST) or print "can't close $test. $!\n";
 
     return $s;
 }
@@ -1098,7 +1055,7 @@ test whether new files appeared in that directory, and report them as
 
 If relative, directory name is with respect to the current directory at
 the moment runtests() was called.  Putting absolute path into 
-C<HARNESS_FILELEAK_IN_DIR> may give more predictable results.
+C<HARNESS_FILELEAK_IN_DIR> may give more predicatable results.
 
 =item C<HARNESS_PERL_SWITCHES>
 
